@@ -330,11 +330,12 @@ def __user_console_select(devs):
                     return False
             return True
 
-        aiqi_blue_type.Print_Scan_Onebot_Device(user_select_buff)
+        aiqi_blue_type.Print_Scan_Onebot_Device(user_select_buff,display="scan device list")
         print(
-            'Please enter the number of the connected index , multiple sequences separated by spaces,Or directly enter, all the default configuration')
-        print('Input sequence, determine the control sequence, please choose according to your needs')
-        user_input = input('(Enter or input index):').split()
+            '①Select the device to be connected according to the index number.Multiple devices are separated by spaces.If you want to select devices 0 and 1, then enter 0   1.'
+            '\nAlso, if you need to select all devices, press Enter.')
+        print('②The input sequence determines the control sequence. So please pay attention to the order of input.')
+        user_input = input('(Enter or Input index):').split()
         if len(user_input) != 0:
             user_input = list(map(int, user_input))
             if checkvalid(user_input):
@@ -385,17 +386,17 @@ async def onebot_getdevices_process():
         await asyncio.sleep(blue_scan_parm.scantimeout + 1)
         await __aiqi_adapter.scan_ctrl(False)
         __wait_char_stats = False
-        print('\nscan stop')
+        # print('\nscan stop')
 
         devices = __bluetooth_scan_list[:]
         devices = __aiqi_adapter.scan_devices_operation(
             devices, blue_scan_parm.scannamelist, blue_scan_parm.scanmaclist)
         __onebot_local_save_list = aiqi_blue_type.select_onebot_devices(
             devices, scan_name=blue_scan_parm.scannamelist)
-        if len(devices) == 0:
+        if len(__onebot_local_save_list) == 0:
             print(
-                "\n" + 'Please Turn on the master motor power switch or Please insert the Bluetooth adapter')
-            sys.exit('aiqi quit')
+                "\n" + 'No device found, please make sure that the power switch or Bluetooth switch is turned on.')
+            sys.exit()
 
         __dev_type = aiqi_blue_type.Read_Onebot_Device_type(__onebot_local_save_list)
         print('Getting information......')
@@ -423,7 +424,7 @@ onebot login
 async def __onebot_login_process():
     global __wait_char_stats
     try:
-        print("Please wait for a connection, up to eight seconds......")
+        print("Waiting for connection.... If there is no connection within 8 seconds, the program will exit due to timeout")
         __wait_char_stats = True
         __print_wait_char(1, 8)
         await __aiqi_adapter.connect(__dev_mac_addr, timeout=8)
@@ -473,10 +474,11 @@ async def __onebot_login_process():
                 await asyncio.sleep(0.05)
                 time.sleep(0.1)
                 if __onebot_login.dev_login_stats:
-                    print('login ok')
+                    pass
+                    # print('login ok')
                 else:
                     print('login err')
-                    sys.exit('login err')
+                    sys.exit()
             else:
                 print('sn err')
                 sys.exit('sn err')
@@ -484,14 +486,16 @@ async def __onebot_login_process():
             print('versin err')
             sys.exit('err')
         else:
-            print('free login')
+            pass
+            # print('free login')
 
     else:
-        print('设备类型不存在:', __dev_type)
-        sys.exit('未知的设备类型')
+        print('Device type does not exist:', __dev_type)
+        sys.exit()
+    print("running...")
 
 
-def Aiqi_Bluetooth_Send(data, log=False):
+def Bluetooth_Data_Send(data, log=False):
     if log:
         Aiqi_Print_HEX(data)
     if __onebot_login.dev_login_stats:
@@ -556,14 +560,18 @@ app_reset : if is 'new' ,will clear local save all devices
 '''
 
 
-def start(app_reset='', scantimeout=5, rssi=-100, namelist=[], maclist=[],disconnect_callback=None):
+def start(app_reset="", scantimeout=5, rssi=-100, namelist=[], maclist=[],disconnect_callback=None):
     global blue_scan_parm, __App_Reset,User_Disconnect_Handle
+    if app_reset != "" and app_reset != "new":
+        print('please check app_reset is "" or "new" ')
+        sys.exit()
     __App_Reset = app_reset.lower()
     print('start')
     parm = aiqi_blue_type.aiqi_bluetooth_scan_class()
     parm.scantimeout = scantimeout
     parm.scannamelist = namelist[:]
     parm.scanmaclist = maclist[:]
+    parm.scanrssi = rssi
     User_Disconnect_Handle = disconnect_callback
     blue_scan_parm = parm
     loop = asyncio.get_event_loop()
